@@ -17,15 +17,18 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Gtk;
-using GtkBeans;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Clients.Classical.Dialogs
 {
 	public class BuilderDialog : Gtk.Dialog
 	{
-		public BuilderDialog (string resourceName, string dialogName) : this (null, resourceName, dialogName)
+		protected ITranslations Translations { get; private set;}
+
+		public BuilderDialog (ITranslations translations, string resourceName, string dialogName) : 
+			this ((System.Reflection.Assembly) null, resourceName, dialogName)
 		{
+			Translations = translations;
 		}
 
 		public BuilderDialog (System.Reflection.Assembly assembly, string resourceName, string dialogName) : 
