@@ -23,18 +23,20 @@ using Mono.Unix;
 using System.Collections.Generic;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 using gbrainy.Clients.Classical.Widgets;
 
 namespace gbrainy.Clients.Classical.Dialogs
 {
 	public class CustomGameDialog : BuilderDialog
 	{
+		// This is static to allow to preserve the selection in different instances
 		static ListStore games_store;
 		[GtkBeans.Builder.Object] Gtk.TreeView treeview;
 		[GtkBeans.Builder.Object] Box preview_vbox;
 		GameDrawingArea drawing_area;
-		GameManager manager;
-		GameManager.GameLocator [] games;
+		GameSession session;
+		GameLocator [] games;
 		bool selection_done;
 
 		const int COL_NAME = 0;
@@ -43,13 +45,13 @@ namespace gbrainy.Clients.Classical.Dialogs
 		const int COL_OBJECT = 3;
 		const int COL_INDEX = 4;
 
-		public CustomGameDialog (GameManager manager) : base ("CustomGameDialog.ui", "customgame")
+		public CustomGameDialog (ITranslations translations, GameSession session) : base (translations, "CustomGameDialog.ui", "customgame")
 		{
 			Game game;
 
 			selection_done = false;
-			this.manager = manager;
-			games = manager.AvailableGames;
+			this.session = session;
+			games = session.GameManager.AvailableGames;
 
 			drawing_area = new GameDrawingArea ();
 			drawing_area.UseSolutionArea = false;
@@ -57,6 +59,48 @@ namespace gbrainy.Clients.Classical.Dialogs
 			drawing_area.Visible = true;
 			treeview.HeadersClickable = true;
 
+			CreateColumnName ();
+			CreateColumnType ();
+			CreateColumnSelected ();
+			LoadGames ();
+
+			treeview.Model = games_store;
+			game = (Game) Activator.CreateInstance (games [0].TypeOf, true);
+			game.Translations = Translations;
+			game.Variant = 0;
+			game.Begin ();
+			drawing_area.Drawable = game;
+			drawing_area.Question = game.Question;
+			treeview.ColumnsAutosize ();
+		}
+
+		void LoadGames ()
+		{
+			if (games_store != null)
+				return;
+
+			games_store = new ListStore (typeof(string), typeof (string), typeof(bool), typeof (Game), typeof (int));
+			games_store.SetSortFunc (0, new Gtk.TreeIterCompareFunc (GameSort));
+			games_store.SetSortColumnId (COL_TYPE, SortType.Ascending);
+				 
+			// Data
+			string type;
+			Game game;
+			for (int i = 0; i < games.Length; i++)
+			{
+				if (games [i].IsGame == false)
+					continue;
+
+				game = (Game) Activator.CreateInstance (games [i].TypeOf, true);
+				game.Translations = Translations;
+				game.Variant = games [i].Variant;
+				type = GameTypesDescription.GetLocalized (Translations, game.Type);
+				games_store.AppendValues (game.Name, type, true, game, i);
+			}
+		}
+
+		void CreateColumnName ()
+		{
 			// Column: Game Name
 			TreeViewColumn name_column = new TreeViewColumn (Catalog.GetString("Game Name"), 
 				new CellRendererText(), "text", 0);
@@ -79,6 +123,10 @@ namespace gbrainy.Clients.Classical.Dialogs
 
 			treeview.AppendColumn (name_column);
 
+		}
+
+		void CreateColumnType ()
+		{
 			// Column: Type
 			TreeViewColumn type_column = new TreeViewColumn (Catalog.GetString("Type"), 
 				new CellRendererText(), "text", 1);
@@ -99,7 +147,11 @@ namespace gbrainy.Clients.Classical.Dialogs
 				column.SortOrder = order;
 				games_store.SetSortColumnId (COL_TYPE, order);
 			};
+		}
 
+
+		void CreateColumnSelected ()
+		{
 			// Column: Selected
 			CellRendererToggle toggle_cell = new CellRendererToggle();
 			TreeViewColumn toggle_column = new TreeViewColumn(Catalog.GetString("Selected"),
@@ -109,40 +161,20 @@ namespace gbrainy.Clients.Classical.Dialogs
 			toggle_column.Expand = false;
 			treeview.CursorChanged += OnCursorChanged;
 			treeview.AppendColumn (toggle_column);
-
-			if (games_store == null) {
-				games_store = new ListStore (typeof(string), typeof (string), typeof(bool), typeof (Game), typeof (int));
-
-				games_store.SetSortFunc (0, new Gtk.TreeIterCompareFunc (GameSort));
-				games_store.SetSortColumnId (COL_TYPE, SortType.Ascending);
-					 
-				// Data
-				string type;
-				for (int i = 0; i < games.Length; i++)
-				{
-					if (games [i].IsGame == false)
-						continue;
-
-					game = (Game) Activator.CreateInstance (games [i].TypeOf, true);
-					game.Variant = games [i].Variant;
-					type = GameTypesDescription.GetLocalized (game.Type);
-					games_store.AppendValues (game.Name, type, true, game, i);
-				}
-			}
-
-			treeview.Model = games_store;
-			game = (Game) Activator.CreateInstance (games [0].TypeOf, true);
-			game.Variant = 0;
-			game.Begin ();
-			drawing_area.Drawable = game;
-			drawing_area.Question = game.Question;
-			treeview.ColumnsAutosize ();
 		}
 
 		public bool SelectionDone {
 			get { return selection_done;}
 		}
 
+		public static void Clear ()
+		{
+			if (games_store != null)
+				games_store.Dispose ();
+
+			games_store = null;
+		}
+
 		int GameSort (Gtk.TreeModel model, Gtk.TreeIter a, Gtk.TreeIter b)
 		{
 			string name_a, name_b;
@@ -224,7 +256,7 @@ namespace gbrainy.Clients.Classical.Dialogs
 			});
 
 			if (selection_done == true)
-				manager.PlayList = play_list.ToArray ();
+				session.PlayList.PlayList = play_list.ToArray ();
 		}
 	}
 }
