@@ -53,7 +53,6 @@ namespace gbrainy.Core.Main
 		private GameManager game_manager;
 		private System.Timers.Timer timer;
 		private bool paused;
-		private string current_time;
 		private TimeSpan one_sec = TimeSpan.FromSeconds (1);
 		private SessionStatus status;
 		private ViewsControler controler;
@@ -61,21 +60,25 @@ namespace gbrainy.Core.Main
 		private PlayerHistory player_history;
 		private int id;
 		private GameSessionHistoryExtended history;
-
+		private GameSessionPlayList play_list;
+		
 		public event EventHandler DrawRequest;
 		public event EventHandler <UpdateUIStateEventArgs> UpdateUIElement;
+		
 	
-		public GameSession ()
+		public GameSession (ITranslations translations)
 		{
+			Translations = translations;
 			id = 0;
 			game_manager = new GameManager ();
+			play_list = new GameSessionPlayList (game_manager);
 			game_time = TimeSpan.Zero;
 
 			timer = new System.Timers.Timer ();
 			timer.Elapsed += TimerUpdater;
 			timer.Interval = (1 * 1000); // 1 second
 
-			controler = new ViewsControler (this);
+			controler = new ViewsControler (translations, this);
 			Status = SessionStatus.NotPlaying;
 			player_history = new PlayerHistory ();
 			history = new GameSessionHistoryExtended ();
@@ -104,13 +107,13 @@ namespace gbrainy.Core.Main
 		}
 	
 		public Types Type {
-			get {return game_manager.GameType; }
-			set {game_manager.GameType = value; }
+			get { return play_list.GameType; }
+			set { play_list.GameType = value; }
 		}
 
 		public GameDifficulty Difficulty {
-			get {return game_manager.Difficulty; }
-			set {game_manager.Difficulty = value; }
+			get { return play_list.Difficulty; }
+			set { play_list.Difficulty = value; }
 		}
 	
 		public string GameTime {
@@ -122,6 +125,11 @@ namespace gbrainy.Core.Main
 			set {paused = value; }
 		}
 
+		public GameSessionPlayList PlayList {
+			get { return play_list; }
+			set { play_list = value; }
+		}
+
 		public Game CurrentGame {
 			get {return current_game; }
 			set {
@@ -148,12 +156,9 @@ namespace gbrainy.Core.Main
 
 		public GameManager GameManager {
 			get { return game_manager;}
-			set { game_manager = value;}
-		}
-
-		public string TimePlayed {
-			get {
-				return (current_time == null) ? TimeSpanToStr (TimeSpan.FromSeconds (0)) : current_time;
+			set {
+				game_manager = value;
+				play_list.GameManager = value;
 			}
 		}
 
@@ -166,6 +171,8 @@ namespace gbrainy.Core.Main
 			}
 		}
 
+		private ITranslations Translations { get; set; }
+
 		public string StatusText {
 			get {
 				if (Status == SessionStatus.NotPlaying || Status == SessionStatus.Finished)
@@ -173,43 +180,21 @@ namespace gbrainy.Core.Main
 
 				string played, time, game;
 
-				played = String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Games played: {0} (Score: {1})"), history.GamesPlayed, history.TotalScore);
-				time = String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Time: {0}"), current_time);
+				played = String.Format (Translations.GetString ("Games played: {0} (Score: {1})"), history.GamesPlayed, history.TotalScore);
+				time = String.Format (Translations.GetString ("Time: {0}"),
+					paused == false ? GameTime : Translations.GetString ("Paused"));
 
 				if (CurrentGame != null) {
 					// Translators: {0} is the name of the game
-	 				game = String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Game: {0}"), CurrentGame.Name);
+	 				game = String.Format (Translations.GetString ("Game: {0}"), CurrentGame.Name);
 					// Translators: text in the status bar: games played - time - game name
-					return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("{0} - {1} - {2}"), played, time, game);
+					return String.Format (Translations.GetString ("{0} - {1} - {2}"), played, time, game);
 				} else {
 					// Translators: text in the status bar: games played - time
-					return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("{0} - {1}"), played, time);
+					return String.Format (Translations.GetString ("{0} - {1}"), played, time);
 				}	
 			}
 		}
-
-		// Summarizes how the game did go
-		public string Result {
-			get {
-				string s;
-
-				if (history.GamesPlayed >= 10) {
-					int percentage_won = (int) (100 * history.GamesWon / history.GamesPlayed);
-					if (percentage_won >= 90)
-						s = ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Outstanding results");
-					else if (percentage_won >= 70)
-						s = ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Excellent results");
-					else if (percentage_won >= 50)
-						s = ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Good results");
-					else if (percentage_won >= 30)
-						s = ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Poor results");
-					else s = ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Disappointing results");
-				} else
-					s = string.Empty;
-	
-				return s;
-			}
-		}
 	
 		public void New ()
 		{
@@ -220,8 +205,6 @@ namespace gbrainy.Core.Main
 			if (Status != SessionStatus.NotPlaying)
 				End ();
 
-			current_time = TimeSpanToStr (game_time);
-
 			history.Clear ();
 			game_time = TimeSpan.Zero;
 			timer.SynchronizingObject = SynchronizingObject;
@@ -258,7 +241,8 @@ namespace gbrainy.Core.Main
 				}
 
 				history.GamesPlayed++;
-				CurrentGame = game_manager.GetPuzzle ();
+				CurrentGame = play_list.GetPuzzle ();
+				CurrentGame.Translations = Translations;
 				CurrentGame.SynchronizingObject = SynchronizingObject;
 				CurrentGame.DrawRequest += GameDrawRequest;
 				CurrentGame.UpdateUIElement += GameUpdateUIElement;
@@ -278,7 +262,6 @@ namespace gbrainy.Core.Main
 		{
 			EnableTimer = false;
 			paused = true;
-			current_time = ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Paused");
 
 			if (CurrentGame != null)
 				CurrentGame.EnableMouseEvents (false);
@@ -315,7 +298,6 @@ namespace gbrainy.Core.Main
 
 				game_time = game_time.Add (one_sec);
 				CurrentGame.GameTime = CurrentGame.GameTime + one_sec;
-				current_time = TimeSpanToStr (game_time);
 			}
 
 			if (UpdateUIElement == null)
