@@ -18,7 +18,8 @@
  */
 
 using System;
-using Mono.Unix;
+
+using gbrainy.Core.Services;
 
 namespace gbrainy.Core.Main
 {
@@ -36,18 +37,18 @@ namespace gbrainy.Core.Main
 	public static class GameTypesDescription
 	{
 		// Type enum to string representation (locale sensitive)
-		static public string GetLocalized (GameTypes type)
+		static public string GetLocalized (ITranslations translations, GameTypes type)
 		{
 			switch (type) 
 			{
 				case GameTypes.LogicPuzzle:
-					return Catalog.GetString ("Logic");
+					return translations.GetString ("Logic");
 				case GameTypes.Memory:
-					return Catalog.GetString ("Memory");
+					return translations.GetString ("Memory");
 				case GameTypes.Calculation:
-					return Catalog.GetString ("Calculation");
+					return translations.GetString ("Calculation");
 				case GameTypes.VerbalAnalogy:
-					return Catalog.GetString ("Verbal");
+					return translations.GetString ("Verbal");
 				default:
 					throw new InvalidOperationException ("Unknown game type");
 			}
