@@ -20,9 +20,6 @@
 using System;
 using System.Collections.Generic;
 
-using Mono.Unix;
-
-
 namespace gbrainy.Core.Main.Verbal
 {
 	public class AnalogiesPairOfWordsCompare : Analogies
@@ -39,7 +36,7 @@ namespace gbrainy.Core.Main.Verbal
 		}
 
 		public override string Name {
-			get { return String.Format (Catalog.GetString ("Pair of words compare #{0}"), Variant);}
+			get { return String.Format (Translations.GetString ("Pair of words compare #{0}"), Variant);}
 		}
 
 		public override Dictionary <int, Analogy> List {
@@ -48,28 +45,48 @@ namespace gbrainy.Core.Main.Verbal
 
 		public override string Question {
 			get {
-				if (current == null)
+				if (Current == null)
 					return string.Empty;
 
-				if (current.answers == null)
-					return current.question;
+				if (Current.answers == null)
+					return Current.question;
 
-				return String.Format (Catalog.GetString (
+				return String.Format (Translations.GetString (
 					"Given the relationship between the two words below, which word has the same relationship to '{0}'?"),
 					sample);
 			}
 		}
 
+		public override string AnswerText {
+			get {
+				string str;
+				string[] items;
+
+				items = Answer.Correct.Split (AnalogiesFactory.Separator);
+
+				str = String.Format (Translations.GetPluralString ("The correct answer is {0}.",
+					"The possible correct answers are {0}.", items.Length),
+					Answer.CorrectShow);
+
+				if (String.IsNullOrEmpty (Rationale))
+					return str;
+
+				// Translators: answer + rationale of the answer
+				return String.Format (Translations.GetString ("{0} {1}"), str, Rationale);
+			}
+		}
+
+
 		protected override void Initialize ()
 		{
-			current = GetNext ();
+			Current = GetNext ();
 
-			if (current == null || current.answers == null)
+			if (Current == null || Current.answers == null)
 				return;
 
 			string [] items;
 
-			items = current.question.Split (AnalogiesFactory.Separator);
+			items = Current.question.Split (AnalogiesFactory.Separator);
 
 			if (items.Length == 2)
 				sample = items [1].Trim ();
@@ -77,7 +94,8 @@ namespace gbrainy.Core.Main.Verbal
 				sample = string.Empty;
 
 			samples = items [0].Trim ();
-			right_answer = current.answers [current.right];
+			Answer.Correct = Current.answers [Current.right];
+			SetAnswerCorrectShow ();
 		}
 	
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
@@ -86,12 +104,12 @@ namespace gbrainy.Core.Main.Verbal
 
 			base.Draw (gr, area_width, area_height, rtl);
 
-			if (current == null || current.answers == null)
+			if (Current == null || Current.answers == null)
 				return;
 
 			gr.SetPangoLargeFontSize ();
 			gr.DrawTextCentered (0.5, y + 0.25,
-				String.Format (Catalog.GetString ("Words: {0}"), samples));
+				String.Format (Translations.GetString ("Words: {0}"), samples));
 		}
 	}
 }
