@@ -18,10 +18,10 @@
  */
 
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Toolkit;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Calculation
 {
@@ -35,7 +35,7 @@ namespace gbrainy.Games.Calculation
 		double correct;
 
 		public override string Name {
-			get {return Catalog.GetString ("Average");}
+			get {return Translations.GetString ("Average");}
 		}
 
 		public override GameTypes Type {
@@ -45,25 +45,25 @@ namespace gbrainy.Games.Calculation
 		public override string Question {
 			get {
 				string nums = string.Empty;
-	
+
 				for (int i = 0; i < numbers.Length - 1; i++)
 					nums += numbers[i] + ", ";
 
 				nums += numbers [numbers.Length - 1];
 
 				return String.Format (
-					Catalog.GetString ("Given the numbers: {0}. Which of the following numbers is the nearest to the average? Answer {1}, {2}, {3} or {4}."), nums,
-					GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3));}
+					Translations.GetString ("Given the numbers: {0}. Which of the following numbers is closest to the average? Answer {1}, {2}, {3} or {4}."), nums,
+					Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2), Answer.GetMultiOption (3));}
 		}
 
 		public override string Tip {
-			get { return Catalog.GetString ("The average of a list of numbers is the sum of all of the numbers divided by the number of items in the list.");}
+			get { return Translations.GetString ("The average of a list of numbers is their sum divided by the number of numbers in the list.");}
 		}
 
 		public override string Rationale {
-			get { 
-				return String.Format (Catalog.GetString ("The result of the operation is {0:##0.###}."), 
-					correct);				
+			get {
+				return String.Format (Translations.GetString ("The result of the operation is {0}."),
+					correct);
 			}
 		}
 
@@ -72,6 +72,7 @@ namespace gbrainy.Games.Calculation
 			bool duplicated;
 			int nums, options_next, dist, num_size, which = 0;
 
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption;
 			switch (CurrentDifficulty) {
 			case GameDifficulty.Easy:
 				nums = 3;
@@ -115,13 +116,13 @@ namespace gbrainy.Games.Calculation
 			while (options_next < options_cnt) {
 				double ans;
 
-				ans = correct + random.Next (dist);
-				duplicated = false;	
+				ans = correct + random.Next (-dist, dist +1);
+				duplicated = false;
 
 				// No repeated answers
 				for (int num = 0; num < options_next; num++)
 				{
-					// Due to decimal precission
+					// Due to decimal precision
 					if (options [num] == ans || options [num] == ans + 1 || options [num] == ans - 1) {
 						duplicated = true;
 						break;
@@ -130,14 +131,14 @@ namespace gbrainy.Games.Calculation
 
 				if (duplicated)
 					continue;
-			
+
 				options [options_next] = ans;
 				options_next++;
 			}
 
 			random_indices = new ArrayListIndicesRandom (options_cnt);
 			random_indices.Initialize ();
-		
+
 			for (int i = 0; i < options_cnt; i++)
 			{
 				if (random_indices [i] == correct_pos) {
@@ -146,13 +147,13 @@ namespace gbrainy.Games.Calculation
 				}
 			}
 
-			right_answer += GetPossibleAnswer (which);
+			Answer.SetMultiOptionAnswer (which, options [correct_pos].ToString ());
 
 			// Options
 			double x = DrawAreaX + 0.25, y = DrawAreaY + 0.16;
 			Container container = new Container (x, y,  1 - (x * 2), 0.6);
 			AddWidget (container);
-	
+
 			for (int i = 0; i < options_cnt; i++)
 			{
 				DrawableArea drawable_area = new DrawableArea (0.3, 0.1);
@@ -160,7 +161,7 @@ namespace gbrainy.Games.Calculation
 				drawable_area.Y = y + i * 0.15;
 				container.AddChild (drawable_area);
 				drawable_area.Data = i;
-				drawable_area.DataEx = GetPossibleAnswer (i);
+				drawable_area.DataEx = Answer.GetMultiOption (i);
 
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 				{
@@ -169,9 +170,19 @@ namespace gbrainy.Games.Calculation
 
 					e.Context.SetPangoLargeFontSize ();
 					e.Context.MoveTo (0.02, 0.02);
-					e.Context.ShowPangoText (String.Format ("{0}) {1:##0.###}", GetPossibleAnswer (n) , options [indx]));
+					e.Context.ShowPangoText (String.Format ("{0}) {1}", Answer.GetMultiOption (n) , options [indx]));
 				};
 			}
 		}
+
+		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
+		{
+			base.Draw (gr, area_width, area_height, rtl);
+
+			gr.SetPangoLargeFontSize ();
+
+			gr.MoveTo (0.1, 0.15);
+			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
+		}
 	}
 }
