@@ -18,7 +18,6 @@
  */
 
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Toolkit;
@@ -34,7 +33,7 @@ namespace gbrainy.Games.Calculation
 		private int answer_idx;
 
 		public override string Name {
-			get {return Catalog.GetString ("Greatest divisor");}
+			get {return Translations.GetString ("Greatest divisor");}
 		}
 
 		public override GameTypes Type {
@@ -42,9 +41,9 @@ namespace gbrainy.Games.Calculation
 		}
 
 		public override string Question {
-			get { return String.Format (Catalog.GetString (
+			get { return String.Format (Translations.GetString (
 				"Which of the possible divisors is the greatest that divides all numbers? Answer {0}, {1}, {2} or {3}."),
-				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3));
+				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2), Answer.GetMultiOption (3));
 			}
 		}
 
@@ -54,6 +53,7 @@ namespace gbrainy.Games.Calculation
 			int n, m;
 			int []mult = new int [3];
 
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption;
 			switch (CurrentDifficulty) {
 			case GameDifficulty.Easy:
 				max_num = 999;
@@ -129,7 +129,7 @@ namespace gbrainy.Games.Calculation
 				}
 			}
 
-			right_answer = answer.ToString ();
+			Answer.SetMultiOptionAnswer (answer_idx, answer.ToString ());
 
 			// Drawing objects
 			Container container = new Container (DrawAreaX + 0.2, DrawAreaY + 0.25, 0.4, answers.Length * 0.15);
@@ -142,14 +142,14 @@ namespace gbrainy.Games.Calculation
 				drawable_area.Y = DrawAreaY + 0.27 + i * 0.15;
 				container.AddChild (drawable_area);
 				drawable_area.Data = i;
-				drawable_area.DataEx = GetPossibleAnswer (i);
+				drawable_area.DataEx = Answer.GetMultiOption (i);
 
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 				{
 					int d = (int) e.Data;
 					e.Context.SetPangoLargeFontSize ();
 					e.Context.MoveTo (0.07, 0.02);
-					e.Context.ShowPangoText (String.Format (Catalog.GetString ("{0}) {1}"), GetPossibleAnswer (d),
+					e.Context.ShowPangoText (String.Format (Translations.GetString ("{0}) {1}"), Answer.GetMultiOption (d),
 						answers[d].ToString ()));
 				};
 			}
@@ -240,7 +240,7 @@ namespace gbrainy.Games.Calculation
 
 			gr.MoveTo (0.05, y);
 			gr.SetPangoLargeFontSize ();
-			gr.ShowPangoText (Catalog.GetString ("Numbers"));
+			gr.ShowPangoText (Translations.GetString ("Numbers"));
 			y += 0.08;
 
 			for (int n = 0; n < numbers.Length; n++)
@@ -254,18 +254,7 @@ namespace gbrainy.Games.Calculation
 			y += 0.16;
 
 			gr.MoveTo (0.05, y);
-			gr.ShowPangoText (Catalog.GetString ("Possible divisors"));
-		}
-
-		public override bool CheckAnswer (string answer)
-		{
-			if (base.CheckAnswer (answer) == true)
-				return true;
-
-			if (String.Compare (answer, GetPossibleAnswer (answer_idx), true) == 0)
-				return true;
-
-			return false;
+			gr.ShowPangoText (Translations.GetString ("Possible divisors"));
 		}
 	}
 }
