@@ -17,7 +17,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
@@ -29,15 +28,15 @@ namespace gbrainy.Games.Logic
 		int rows, columns, depth;
 
 		public override string Name {
-			get {return Catalog.GetString ("3D Cube");}
+			get {return Translations.GetString ("3D Cube");}
 		}
 
 		public override string Question {
-			get {return Catalog.GetString ("How many small cubes does it take to build the large cube below? Answer using a number.");}
+			get {return Translations.GetString ("How many small cubes does it take to build the large cube below? Answer using a number.");}
 		}
 
 		public override string Tip {
-			get { return Catalog.GetString ("A cube is a regular solid object having six congruent square faces.");}
+			get { return Translations.GetString ("A cube is a regular solid object having six congruent square faces.");}
 		}
 
 		protected override void Initialize ()
@@ -59,7 +58,7 @@ namespace gbrainy.Games.Logic
 
 			rows = columns = depth = 4 + random.Next (max_random);
 			ans = rows * columns * depth;
-			right_answer += ans.ToString ();	
+			Answer.Correct = ans.ToString ();	
 		}
 
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
