@@ -18,9 +18,9 @@
  */
 
 using Cairo;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -32,15 +32,11 @@ namespace gbrainy.Games.Logic
 		private const double line_width = 0.001;
 
 		public override string Name {
-			get {return Catalog.GetString ("Cover percentage");}
+			get {return Translations.GetString ("Cover percentage");}
 		}
 
 		public override string Question {
-			get {return Catalog.GetString ("What percentage of the figure is colored?");} 
-		}
-
-		public override string AnswerCheckExpression {
-			get { return "[0-9]+";}
+			get {return Translations.GetString ("What percentage of the figure is colored?");} 
 		}
 
 		protected override void Initialize ()
@@ -74,7 +70,8 @@ namespace gbrainy.Games.Logic
 
 			partial_zones = random.Next (2) + 1;
 			total += partial_zones * 5;
-			right_answer = total.ToString ();
+			Answer.Correct = total.ToString ();
+			Answer.CheckExpression = "[0-9]+";
 		}
 
 		private static void Fill (CairoContextEx gr, double x, double y, double w, double h)
@@ -110,7 +107,7 @@ namespace gbrainy.Games.Logic
 			gr.Restore ();
 		}
 
-		private void CoverZone (CairoContextEx gr, double x, double y)
+		static private void CoverZone (CairoContextEx gr, double x, double y)
 		{
 			Fill (gr, x + line_width, y + line_width , (width / 2) - (line_width * 2), (height / 2) - (line_width * 2));
 		}
