@@ -19,9 +19,9 @@
 
 
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -29,20 +29,20 @@ namespace gbrainy.Games.Logic
 	{
 		int type;
 		public override string Name {
-			get {return Catalog.GetString ("Four sided");}
+			get {return Translations.GetString ("Four sided");}
 		}
 
 		public override string Question {
-			get {return Catalog.GetString ("How many four sided figures do you count in the figure below?");} 
+			get {return Translations.GetString ("How many four sided figures do you count in the figure below?");} 
 		}
 
 		public override string Tip {
-			get { return Catalog.GetString ("A four sided figure can be embedded inside another figure.");}
+			get { return Translations.GetString ("A four sided figure can be embedded inside another figure.");}
 		}
 
 		public override string Rationale {
 			get { 
-				return String.Format (Catalog.GetString ("The four sided figures are made by connecting the following points: {0}"),
+				return String.Format (Translations.GetString ("The four sided figures are made by connecting the following points: {0}"),
 					(type == 0) ? "abde, degh, bcef, efhi, acdf, dfgi, abhg, bcih, acig, aghe, aefc, deig, bcie." : 
 					"abde, degh, bcef, efhi, acdf, dfgi, abhg, bcih, acig, aghe, aefc, deig, bcie, acde, cehi, abeg, egif.");
 			}
@@ -57,9 +57,9 @@ namespace gbrainy.Games.Logic
 
 		
 			if (type == 0)	
-				right_answer = "13";
+				Answer.Correct = "13";
 			else
-				right_answer = "17";
+				Answer.Correct = "17";
 		}
 
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
@@ -90,7 +90,7 @@ namespace gbrainy.Games.Logic
 				gr.Stroke ();
 			}
 
-			if (DrawAnswer == false)
+			if (Answer.Draw == false)
 				return;
 
 			// References
