@@ -17,10 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -29,19 +29,22 @@ namespace gbrainy.Games.Logic
 		int people, handshakes;
 
 		public override string Name {
-			get {return Catalog.GetString ("Handshakes");}
+			get {return Translations.GetString ("Handshakes");}
 		}
 
 		public override string Question {
 			get {return String.Format (
-				Catalog.GetString ("All attendees to a party are introduced to one another. {0} handshakes are made in total. How many people are attending the party?"), 				handshakes);
+				Translations.GetString ("All attendees to a party are introduced to one another. {0} handshakes are made in total. How many people are attending the party?"), 				handshakes);
 			}
 		}
 
 		public override string Tip {
-			get { return Catalog.GetString ("Try to imagine a situation in which you are meeting a small number of people.");}
+			get { return Translations.GetString ("Try to imagine a situation in which you are meeting a small number of people.");}
 		}
 
+		public override string Rationale {
+			get { return Translations.GetString ("Using n as the total number of people, the first person handshakes n-1 people, the second n-2 people, etc. The result is the sum of the first n-1 consecutive numbers: 1+2+3+...+(n-1).");}
+		}
 		protected override void Initialize ()
 		{
 			handshakes = 0;
@@ -62,7 +65,7 @@ namespace gbrainy.Games.Logic
 			for (int i = 1; i < people; i++)
 				handshakes += i;
 		
-			right_answer = people.ToString ();
+			Answer.Correct = people.ToString ();
 		}
 
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
