@@ -52,6 +52,7 @@ namespace gbrainy.Games.Logic
 			}
 		}
 
+		private const double cercle_size = 0.15;
 		private double small_size = 0.01;
 		private double medium_size = 0.02;
 	  	private ArrayList questions;
@@ -73,25 +74,25 @@ namespace gbrainy.Games.Logic
 		private const double pos7_y = 0.11;
 
 		public override string Name {
-			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Most in common");}
+			get {return Translations.GetString ("Most in common");}
 		}
 
 		public override string Question {
 			get {return String.Format (
-				ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Which of the possible answers have the most in common with the four given figures? Answer {0}, {1}, {2} or {3}."),
+				Translations.GetString ("Which of the possible answers have the most in common with the four given figures? Answer {0}, {1}, {2} or {3}."),
 					Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2), Answer.GetMultiOption (3));}
 		}
 
 		public override string Tip {
-			get { return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Think of the common elements that the given figures have inside them.");}
+			get { return Translations.GetString ("Think of the common elements that the given figures have inside them.");}
 		}
 
 		public override string Rationale {
 			get {
 				if (CurrentDifficulty ==  GameDifficulty.Easy)
-					return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("It has the same number of elements inside the figure as the given figures.");
+					return Translations.GetString ("It has the same number of elements inside the figure as the given figures.");
 				else
-					return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("It is the figure with the most elements in common compared to the given figures.");
+					return Translations.GetString ("It is the figure with the most elements in common compared to the given figures.");
 			}
 		}
 
@@ -184,7 +185,7 @@ namespace gbrainy.Games.Logic
 			for (int i = 0; i < random_indices_answers.Count; i++)
 			{
 				drawable_area = new DrawableArea (figure_size, figure_size + 0.05);
-				drawable_area.SelectedArea = new Rectangle (0.05, 0.05, 0.15, 0.15);
+				drawable_area.SelectedArea = new Rectangle (0.05, 0.05, cercle_size, cercle_size);
 				drawable_area.Data = i;
 				drawable_area.DataEx = Answer.GetMultiOption (i);
 
@@ -193,8 +194,7 @@ namespace gbrainy.Games.Logic
 					int n = (int) e.Data;
 
 					DrawFigure (e.Context, 0.05, 0.05, (FigureElement []) answers[random_indices_answers[n]]);
-					e.Context.MoveTo (0.05, 0.22);
-					e.Context.ShowPangoText (Answer.GetFigureName (n));
+					e.Context.DrawTextCentered (x + (cercle_size / 2), 0.25, Answer.GetFigureName (n));
 				};
 
 				container.AddChild (drawable_area);
@@ -286,7 +286,6 @@ namespace gbrainy.Games.Logic
 
 		private void DrawFigure (CairoContextEx gr, double x, double y, FigureElement[] figure)
 		{
-			const double cercle_size = 0.15;
 			gr.Stroke ();
 			gr.Arc (x + cercle_size / 2, y + cercle_size / 2, cercle_size / 2, 0, 2 * Math.PI);
 			gr.Stroke ();
@@ -311,7 +310,7 @@ namespace gbrainy.Games.Logic
 			y += 0.28;
 			x = DrawAreaX;
 			gr.MoveTo (x - 0.06, y);
-			gr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Choose one of the following:"));
+			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
 			gr.Stroke ();
 		}
 	}
