@@ -18,11 +18,11 @@
  */
 
 using Cairo;
-using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Toolkit;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -50,19 +50,19 @@ namespace gbrainy.Games.Logic
 		};
 
 		public override string Name {
-			get {return Catalog.GetString ("Next figure");}
+			get {return Translations.GetString ("Next figure");}
 		}
 
 		public override string Question {
 			get {return String.Format (
-				Catalog.GetString ("Which is the next logical figure in the sequence? Answer {0}, {1} or {2}."),
-				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2));} 
+				Translations.GetString ("Which is the next logical figure in the sequence? Answer {0}, {1} or {2}."),
+				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2));} 
 		}
 
 
 		public override string Rationale {
 			get {
-				return Catalog.GetString ("From first figure, the top circle advances by two positions clockwise, while the left circle goes backwards one position.");
+				return Translations.GetString ("From first figure, the top circle advances by two positions clockwise, while the left circle goes backwards one position.");
 			}
 		}
 
@@ -70,16 +70,17 @@ namespace gbrainy.Games.Logic
 		{
 			random_indices = new ArrayListIndicesRandom ((int) Figures.Last);
 			random_indices.Initialize ();
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption | GameAnswerCheckAttributes.IgnoreSpaces;
 
 			for (int i = 0; i < (int) Figures.Last; i++)
 			{
 				if (random_indices[i] == (int) Figures.Third) {
-					right_answer = GetPossibleAnswer (i);
+					Answer.SetMultiOptionAnswer (i, Answer.GetFigureName (i));
 					break;
 				}
 			}
 
-			HorizontalContainer container = new HorizontalContainer (DrawAreaX, DrawAreaY + figure_size + 0.16, 					0.8, 0.3);
+			HorizontalContainer container = new HorizontalContainer (DrawAreaX, DrawAreaY + figure_size + 0.16, 0.8, 0.3);
 
 			DrawableArea drawable_area;
 			AddWidget (container);
@@ -89,7 +90,7 @@ namespace gbrainy.Games.Logic
 				drawable_area = new DrawableArea (space_figures, 0.2);						
 				drawable_area.SelectedArea = new Rectangle (0, 0, figure_size, figure_size);
 				drawable_area.Data = i;
-				drawable_area.DataEx = GetPossibleAnswer (i);
+				drawable_area.DataEx = Answer.GetMultiOption (i);
 				container.AddChild (drawable_area);
 
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
@@ -111,13 +112,13 @@ namespace gbrainy.Games.Logic
 					}
 
 					e.Context.MoveTo (0.02, 0.25);
-					e.Context.ShowPangoText (GetPossibleFigureAnswer (n));
+					e.Context.ShowPangoText (Answer.GetFigureName (n));
 					e.Context.Stroke ();
 				};
 			}
 		}
 
-		static private void DrawDiamon (CairoContextEx gr, double x, double y, CerclePosition cercles)
+		static private void DrawDiamon (CairoContextEx gr, double x, double y, CerclePosition circles)
 		{	
 			double distance = 0.04;
 
@@ -128,22 +129,22 @@ namespace gbrainy.Games.Logic
 			gr.LineTo (x + figure_size / 2, y);
 			gr.Stroke ();
 
-			if ((cercles & CerclePosition.Top) == CerclePosition.Top) {
+			if ((circles & CerclePosition.Top) == CerclePosition.Top) {
 				gr.Arc (x + figure_size / 2, y + distance, 0.01, 0, 2 * Math.PI);	
 				gr.Stroke ();
 			}
 
-			if ((cercles & CerclePosition.Right) == CerclePosition.Right) {
+			if ((circles & CerclePosition.Right) == CerclePosition.Right) {
 				gr.Arc (x + figure_size - distance, y + figure_size / 2, 0.01, 0, 2 * Math.PI);	
 				gr.Stroke ();
 			}
 
-			if ((cercles & CerclePosition.Bottom) == CerclePosition.Bottom) {
+			if ((circles & CerclePosition.Bottom) == CerclePosition.Bottom) {
 				gr.Arc (x + figure_size / 2, y + figure_size - distance, 0.01, 0, 2 * Math.PI);	
 				gr.Stroke ();
 			}
 
-			if ((cercles & CerclePosition.Left) == CerclePosition.Left) {
+			if ((circles & CerclePosition.Left) == CerclePosition.Left) {
 				gr.Arc (x + distance, y + figure_size / 2, 0.01, 0, 2 * Math.PI);
 				gr.Stroke ();
 			}
@@ -162,7 +163,7 @@ namespace gbrainy.Games.Logic
 		
 			y += figure_size + 0.06;
 			gr.MoveTo (x, y);
-			gr.ShowPangoText (Catalog.GetString ("Possible answers are:"));
+			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
 			gr.Stroke ();
 		}
 	}
