@@ -18,10 +18,10 @@
  */
 
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Toolkit;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -33,7 +33,7 @@ namespace gbrainy.Games.Logic
 			Numbers,
 			Last = Numbers,
 		};
-		
+
 		ArrayListIndicesRandom random_indices;
 		GameType gametype;
 		const int max_equations = 5;
@@ -50,35 +50,35 @@ namespace gbrainy.Games.Logic
 		string [] equations;
 
 		public override string Name {
-			get {return Catalog.GetString ("Ostracism");}
+			get {return Translations.GetString ("Ostracism");}
 		}
 
 		public override string Question {
 			get {return String.Format (
-				Catalog.GetString ("Which element does not belong to the group? It is not related to divisibility of the numbers. Answer {0}, {1}, {2}, {3} or {4}."),
-				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3), GetPossibleAnswer (4));}
+				Translations.GetString ("Which element does not belong to the group? It is not related to any arithmetical of the numbers. Answer {0}, {1}, {2}, {3} or {4}."),
+				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2), Answer.GetMultiOption (3), Answer.GetMultiOption (4));}
 		}
 
 		public override string Tip {
 			get {
 				switch (gametype) {
 				case GameType.Equations:
-					return Catalog.GetString ("The criteria for deciding if an equation belongs to the group is not arithmetical.");
+					return Translations.GetString ("The criteria for deciding if an equation belongs to the group is not arithmetical.");
 				case GameType.Numbers:
-					return Catalog.GetString ("Consider that every number that belongs to the group has two parts that are related.");
+					return Translations.GetString ("Consider that every number that belongs to the group has two parts that are related.");
 				default:
 					throw new InvalidOperationException ();
 				}
-			}	
+			}
 		}
 
 		public override string Rationale {
 			get {
 				switch (gametype) {
 				case GameType.Equations:
-					return Catalog.GetString ("In all the other equations the digits from the left side appear also in the right side.");
+					return Translations.GetString ("In all the other equations the digits from the left side also appear on the right side.");
 				case GameType.Numbers:
-					return Catalog.GetString ("In all the other numbers the last three digits are the square of the first two digits.");
+					return Translations.GetString ("In all the other numbers the last three digits are the square of the first two digits.");
 				default:
 					throw new InvalidOperationException ();
 				}
@@ -87,10 +87,14 @@ namespace gbrainy.Games.Logic
 
 		protected override void Initialize ()
 		{
+			double pos_x = 0, sel_width;
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption;
 			gametype = (GameType) random.Next ((int) GameType.Last + 1);
 
 			switch (gametype) {
 			case GameType.Equations:
+				pos_x = 0.1;
+				sel_width = 0.5;
 				equations = equations_a;
 				break;
 			case GameType.Numbers:
@@ -99,6 +103,8 @@ namespace gbrainy.Games.Logic
 				int [] seeds = {25, 26, 28, 30, 18, 21, 22};
 				ArrayListIndicesRandom random_seeds = new ArrayListIndicesRandom (seeds.Length);
 
+				pos_x = 0.2;
+				sel_width = 0.32;
 				// Make sure that one of the numbers only is not even or odd to avoid
 				// this rationale as valid answer too
 				do
@@ -127,27 +133,26 @@ namespace gbrainy.Games.Logic
 
 			random_indices = new ArrayListIndicesRandom (equations.Length);
 			random_indices.Initialize ();
-			right_answer = string.Empty;
 
 			for (int i = 0; i < random_indices.Count; i++)
 			{
 				if (random_indices[i] == wrong_answer) {
-					right_answer = GetPossibleAnswer (i);
+					Answer.SetMultiOptionAnswer (i, Answer.GetFigureName (i));
 					break;
 				}
 			}
 
-			Container container = new Container (DrawAreaX + 0.1, DrawAreaY + 0.2, 0.5, random_indices.Count * 0.1);
+			Container container = new Container (DrawAreaX + pos_x, DrawAreaY + 0.2, 0.5, random_indices.Count * 0.1);
 			AddWidget (container);
 
 			for (int i = 0; i < random_indices.Count; i++)
 			{
-				DrawableArea drawable_area = new DrawableArea (0.5, 0.1);
-				drawable_area.X = DrawAreaX + 0.1;
+				DrawableArea drawable_area = new DrawableArea (sel_width, 0.1);
+				drawable_area.X = DrawAreaX + pos_x;
 				drawable_area.Y = DrawAreaY + 0.2 + i * 0.1;
 				container.AddChild (drawable_area);
 				drawable_area.Data = i;
-				drawable_area.DataEx = GetPossibleAnswer (i);
+				drawable_area.DataEx = Answer.GetMultiOption (i);
 
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 				{
@@ -156,9 +161,19 @@ namespace gbrainy.Games.Logic
 					e.Context.SetPangoLargeFontSize ();
 					e.Context.MoveTo (0.05, 0.02);
 					// Translators: this "option) answer" for example "a) "21 x 60 = 1260". This should not be changed for most of the languages
-					e.Context.ShowPangoText (String.Format (Catalog.GetString ("{0}) {1}"), GetPossibleAnswer (n), equations [random_indices[n]]));
+					e.Context.ShowPangoText (String.Format (Translations.GetString ("{0}) {1}"), Answer.GetMultiOption (n), equations [random_indices[n]]));
 				};
 			}
 		}
+
+		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
+		{
+			base.Draw (gr, area_width, area_height, rtl);
+
+			gr.SetPangoLargeFontSize ();
+
+			gr.MoveTo (0.1, 0.15);
+			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
+		}
 	}
 }
