@@ -18,7 +18,6 @@
  */
 
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 
@@ -55,21 +54,21 @@ namespace gbrainy.Games.Logic
 		};
 
 		public override string Name {
-			get {return Catalog.GetString ("Triangles with numbers");}
+			get {return Translations.GetString ("Triangles with numbers");}
 		}
 
 		public override string Question {
-			get {return Catalog.GetString ("Which number should replace the question mark below?");} 
+			get {return Translations.GetString ("Which number should replace the question mark below?");} 
 		}
 
 
 		public override string Tip {
-			get { return Catalog.GetString ("All the triangles share a property and are independent of the rest.");}
+			get { return Translations.GetString ("All the triangles share a property and are independent of the rest.");}
 		}
 
 		public override string Rationale {
 			get {
-				return String.Format (Catalog.GetString ("The result of multiplying the two numbers inside every triangle is {0}."), answer_number);
+				return String.Format (Translations.GetString ("The result of multiplying the two numbers inside every triangle is {0}."), answer_number);
 			}
 		}
 
@@ -78,15 +77,15 @@ namespace gbrainy.Games.Logic
 			group = random.Next (3);
 			switch (group) {
 			case 0:
-				right_answer = "10";
+				Answer.Correct = "10";
 				answer_number = "210";
 				break;
 			case 1:
-				right_answer = "160";
+				Answer.Correct = "160";
 				answer_number = "160";
 				break;
 			case 2:
-				right_answer = "60";
+				Answer.Correct = "60";
 				answer_number = "120";
 				break;
 			}
