@@ -19,7 +19,6 @@
 
 using System;
 using Cairo;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Toolkit;
@@ -48,7 +47,7 @@ namespace gbrainy.Games.Memory
 		private const double block_space = 0.35;
 
 		public override string Name {
-			get {return Catalog.GetString ("Colored figures");}
+			get {return Translations.GetString ("Colored figures");}
 		}
 
 		public override bool UsesColors {
@@ -57,12 +56,14 @@ namespace gbrainy.Games.Memory
 
 		public override string MemoryQuestion {
 			get { return String.Format (
-				Catalog.GetString ("Which of these figures was previously shown? Answer {0}, {1}, {2} or {3}."),
-				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3));}
+				Translations.GetString ("Which of these figures was previously shown? Answer {0}, {1}, {2} or {3}."),
+				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2), Answer.GetMultiOption (3));}
 		}
 
 		protected override void Initialize ()
 		{
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption | GameAnswerCheckAttributes.IgnoreSpaces;
+
 			switch (CurrentDifficulty) {
 			case GameDifficulty.Easy:
 				columns = rows = 5;
@@ -80,7 +81,7 @@ namespace gbrainy.Games.Memory
 			rect_h = 0.3 / columns;
 			squares_colours = new SquareColor [squares * answers];
 			color_sheme = random.Next (2);
-			palette = new ColorPalette ();
+			palette = new ColorPalette (Translations);
 
 			for (int i = 0; i < squares; i++)
 				squares_colours[i] = (SquareColor) random.Next ((int) SquareColor.Length);
@@ -94,7 +95,7 @@ namespace gbrainy.Games.Memory
 
 			for (int i = 0; i < answers_order.Count; i++) {
 				if (answers_order[i] == 0) {
-					right_answer += GetPossibleAnswer (i);
+					Answer.SetMultiOptionAnswer (i, Answer.GetFigureName (i));
 					break;
 				}
 			}
@@ -115,7 +116,7 @@ namespace gbrainy.Games.Memory
 				container.AddChild (drawable_area);
 				drawable_area.SelectedArea = new Rectangle (0.05, 0, 0.3, 0.3);
 				drawable_area.Data = i;
-				drawable_area.DataEx = GetPossibleAnswer (i);
+				drawable_area.DataEx = Answer.GetMultiOption (i);
 
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 				{
@@ -124,7 +125,7 @@ namespace gbrainy.Games.Memory
 					palette.Alpha = alpha;
 					DrawSquare (e.Context, 0.05, 0, squares_colours, squares * answers_order[n]);
 					e.Context.MoveTo (0.05, 0 + block_space - 0.02);
-					e.Context.ShowPangoText (GetPossibleFigureAnswer (n));
+					e.Context.ShowPangoText (Answer.GetFigureName (n));
 					e.Context.Stroke ();
 				};
 			}
