@@ -20,7 +20,6 @@
 using System;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Memory
 {
@@ -33,7 +32,7 @@ namespace gbrainy.Games.Memory
 		private ArrayListIndicesRandom color_order;
 
 		public override string Name {
-			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Colored text");}
+			get {return Translations.GetString ("Colored text");}
 		}
 
 		public override bool UsesColors {
@@ -42,7 +41,7 @@ namespace gbrainy.Games.Memory
 
 		public override string MemoryQuestion {
 			get { 
-				return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("What was the color of the text that said '{0}'?"), question_colorname);}
+				return String.Format (Translations.GetString ("What was the color of the text that said '{0}'?"), question_colorname);}
 		}
 
 		protected override void Initialize ()
@@ -61,7 +60,7 @@ namespace gbrainy.Games.Memory
 				break;
 			}
 
-			palette = new ColorPalette ();
+			palette = new ColorPalette (Translations);
 
 			// It is not acceptable that all the random colors names match the right colors
 			while (done == false) {
